@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_sh.c,v 1.75 2007/06/07 15:36:24 debug Exp $
+ *  $Id: cpu_sh.c,v 1.76.2.1 2008/01/18 19:12:26 debug Exp $
  *
  *  Hitachi SuperH ("SH") CPU emulation.
  *
@@ -50,7 +50,6 @@
 #include "misc.h"
 #include "settings.h"
 #include "symbol.h"
-#include "timer.h"
 
 #include "sh4_exception.h"
 #include "sh4_mmu.h"
@@ -62,7 +61,6 @@
 
 
 extern int quiet_mode;
-extern int native_code_translation_enabled;
 
 void sh_pc_to_pointers(struct cpu *);
 
@@ -224,10 +222,6 @@ int sh_cpu_new(struct cpu *cpu, struct memory *mem, struct machine *machine,
 
 	sh_update_interrupt_priorities(cpu);
 
-	if (native_code_translation_enabled)
-		cpu->sampling_timer = timer_add(CPU_SAMPLE_TIMER_HZ,
-		    sh_timer_sample_tick, cpu);
-
 	return 1;
 }
 
