@@ -2,7 +2,7 @@
 #define	CPU_H
 
 /*
- *  Copyright (C) 2005-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -28,7 +28,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu.h,v 1.128 2007/06/14 04:53:14 debug Exp $
+ *  $Id: cpu.h,v 1.143.2.1 2008/01/18 19:12:31 debug Exp $
  *
  *  CPU-related definitions.
  */
@@ -47,25 +47,29 @@
 /*
  *  Dyntrans misc declarations, used throughout the dyntrans code.
  *
- *  Note that there is space for all instruction calls within a page,
- *  and then 2 more. The first one of these "extra" instruction slots is
- *  the end-of-page slot. It transfers control to the first instruction
- *  slot on the next (virtual) page.
+ *  Note that there is space for all instruction calls within a page, and then
+ *  two more. The first one of these "extra" instruction slots is the end-of-
+ *  page slot. It transfers control to the first instruction slot on the next
+ *  (virtual) page.
  *
- *  The second of these extra instruction slots is an additional 
- *  end-of-page slot for delay-slot architectures. On e.g. MIPS, a branch
- *  instruction can "nullify" (skip) the delay-slot. If the end-of-page
- *  slot is skipped, then we end up one step after that. That's where the
- *  end_of_page2 slot is. :)
+ *  The second of these extra instruction slots is an additional end-of-page
+ *  slot for delay-slot architectures. On e.g. MIPS, a branch instruction can
+ *  "nullify" (skip) the delay-slot. If the end-of-page slot is skipped, then
+ *  we end up one step after that. That's where the end_of_page2 slot is. :)
  *
- *  next_ofs points to the next page in a chain of possible pages.
- *  (several pages can be in the same chain, but only one matches the
- *  specific physaddr.)
+ *  next_ofs points to the next page in a chain of possible pages. (Several
+ *  pages can be in the same chain, but only one matches the specific physaddr.)
  *
- *  translations is a tiny bitmap indicating which parts of the page have
- *  actual translations. Bit 0 corresponds to the lowest 1/32th of the page,
- *  bit 1 to the second-lowest 1/32th, and so on. This speeds up page
- *  invalidations, since only part of the page need to be reset.
+ *  translations_bitmap is a tiny bitmap indicating which parts of the page have
+ *  actual translations. Bit 0 corresponds to the lowest 1/32th of the page, bit
+ *  1 to the second-lowest 1/32th, and so on. This speeds up page invalidations,
+ *  since only part of the page need to be reset.
+ *
+ *  translation_ranges_ofs is an offset within the translation cache to a short
+ *  list of ranges for this physpage which contain code. The list is of fixed
+ *  length; to extend the list, the list should be made to point to another
+ *  list, and so forth. (Bad, O(n) find/insert complexity. Should be fixed some
+ *  day. TODO)  See definition of physpage_ranges below.
  */
 #define DYNTRANS_MISC_DECLARATIONS(arch,ARCH,addrtype)  struct \
 	arch ## _instr_call {					\
@@ -77,7 +81,8 @@
 	struct arch ## _tc_physpage {					\
 		struct arch ## _instr_call ics[ARCH ## _IC_ENTRIES_PER_PAGE+2];\
 		uint32_t	next_ofs;	/*  (0 for end of chain)  */ \
-		uint32_t	translations;				\
+		uint32_t	translations_bitmap;			\
+		uint32_t	translation_ranges_ofs;			\
 		addrtype	physaddr;				\
 	};								\
 									\
@@ -105,6 +110,21 @@
 		int				refcount;		\
 	};
 
+
+/*
+ *  This structure contains a list of ranges within an emulated
+ *  physical page that contain translatable code.
+ */
+#define	PHYSPAGE_RANGES_ENTRIES_PER_LIST		20
+struct physpage_ranges {
+	uint32_t	next_ofs;	/*  0 for end of chain  */
+	uint32_t	n_entries_used;
+	uint16_t	base[PHYSPAGE_RANGES_ENTRIES_PER_LIST];
+	uint16_t	length[PHYSPAGE_RANGES_ENTRIES_PER_LIST];
+	uint16_t	count[PHYSPAGE_RANGES_ENTRIES_PER_LIST];
+};
+
+
 /*
  *  Dyntrans "Instruction Translation Cache":
  *
@@ -213,6 +233,7 @@
 /*  Include all CPUs' header files here:  */
 #include "cpu_alpha.h"
 #include "cpu_arm.h"
+#include "cpu_m32r.h"
 #include "cpu_m88k.h"
 #include "cpu_mips.h"
 #include "cpu_ppc.h"
@@ -293,7 +314,7 @@ struct cpu_family {
 #define	N_SAFE_DYNTRANS_LIMIT_SHIFT	14
 #define	N_SAFE_DYNTRANS_LIMIT	((1 << (N_SAFE_DYNTRANS_LIMIT_SHIFT - 1)) - 1)
 
-#define	MAX_DYNTRANS_READAHEAD		1024
+#define	MAX_DYNTRANS_READAHEAD		128
 
 #define	DEFAULT_DYNTRANS_CACHE_SIZE	(48*1048576)
 #define	DYNTRANS_CACHE_MARGIN		200000
@@ -301,9 +322,6 @@ struct cpu_family {
 #define	N_BASE_TABLE_ENTRIES		65536
 #define	PAGENR_TO_TABLE_INDEX(a)	((a) & (N_BASE_TABLE_ENTRIES-1))
 
-#define	CPU_SAMPLE_TIMER_HZ		TIMER_BASE_FREQUENCY
-#define	N_PADDR_SAMPLES			64
-
 
 /*
  *  The generic CPU struct:
@@ -319,7 +337,7 @@ struct cpu {
 	/*  CPU-specific name, e.g. "R2000", "21164PC", etc.  */
 	char		*name;
 
-	/*  Full "path" to the CPU, e.g. "emul[0].machine[0].cpu[0]":  */
+	/*  Full "path" to the CPU, e.g. "machine[0].cpu[0]":  */
 	char		*path;
 
 	/*  Nr of instructions executed, etc.:  */
@@ -329,18 +347,6 @@ struct cpu {
 	int64_t		ninstrs_since_gettimeofday;
 	struct timeval	starttime;
 
-	/*
-	 *  Periodic sampling of the physical address corresponding to the
-	 *  emulated program counter:
-	 *
-	 *  (Used to decide whether or not native code generation is worth
-	 *  the effort.)
-	 */
-	struct timer	*sampling_timer;
-	uint8_t		sampling;	/*  1 = turned on  */
-	int16_t		sampling_curindex;
-	uint64_t	*sampling_paddr;
-
 	/*  EMUL_LITTLE_ENDIAN or EMUL_BIG_ENDIAN.  */
 	uint8_t		byte_order;
 
@@ -419,7 +425,6 @@ struct cpu {
 	 *  ahead of the current (emulated) instruction pointer.
 	 */
 
-	/*  Non-zero when translating ahead of the current instruction:  */
 	int		translation_readahead;
 
 	/*  Instruction translation cache:  */
@@ -438,6 +443,7 @@ struct cpu {
 	union {
 		struct alpha_cpu      alpha;
 		struct arm_cpu        arm;
+		struct m32r_cpu       m32r;
 		struct m88k_cpu       m88k;
 		struct mips_cpu       mips;
 		struct ppc_cpu        ppc;
