@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003-2007  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2003-2008  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: main.c,v 1.305 2007/06/15 17:02:38 debug Exp $
+ *  $Id: main.c,v 1.311.2.1 2008/01/18 19:12:24 debug Exp $
  */
 
 #include <stdio.h>
@@ -61,8 +61,7 @@ char **extra_argv;
 char *progname;
 
 size_t dyntrans_cache_size = DEFAULT_DYNTRANS_CACHE_SIZE;
-int native_code_translation_enabled = 0;
-int skip_srandom_call = 0;
+static int skip_srandom_call = 0;
 
 
 /*****************************************************************************
@@ -197,11 +196,7 @@ void internal_w(char *arg)
  */
 static void usage(int longusage)
 {
-	printf("GXemul");
-#ifdef VERSION
-	printf(" " VERSION);
-#endif
-	printf("    Copyright (C) 2003-2007  Anders Gavare\n");
+	printf("GXemul "VERSION"    Copyright (C) 2003-2008  Anders Gavare\n");
 	printf("Read the source code and/or documentation for "
 	    "other Copyright messages.\n");
 
@@ -308,9 +303,6 @@ static void usage(int longusage)
 	    " get a list of\n            available emulation modes)\n");
 
 	printf("\nGeneral options:\n");
-	printf("  -b        enable native code generation, if available\n");
-	printf("  -B        disable native code generation (this is "
-	    "the default)\n");
 	printf("  -c cmd    add cmd as a command to run before starting "
 	    "the simulation\n");
 	printf("  -D        skip the srandom call at startup\n");
@@ -356,10 +348,10 @@ int get_cmd_args(int argc, char *argv[], struct emul *emul,
 	char *type = NULL, *subtype = NULL;
 	int n_cpus_set = 0;
 	int msopts = 0;		/*  Machine-specific options used  */
-	struct machine *m = emul_add_machine(emul, "default");
+	struct machine *m = emul_add_machine(emul, NULL);
 
 	char *opts =
-	    "bBC:c:Dd:E:e:HhI:iJj:k:KM:Nn:Oo:p:QqRrSs:TtUu:VvW:"
+	    "C:c:Dd:E:e:HhI:iJj:k:KM:Nn:Oo:p:QqRrSs:TtUu:VvW:"
 #ifdef WITH_X11
 	    "XxY:"
 #endif
@@ -367,12 +359,6 @@ int get_cmd_args(int argc, char *argv[], struct emul *emul,
 
 	while ((ch = getopt(argc, argv, opts)) != -1) {
 		switch (ch) {
-		case 'b':
-			native_code_translation_enabled = 1;
-			break;
-		case 'B':
-			native_code_translation_enabled = 0;
-			break;
 		case 'C':
 			CHECK_ALLOCATION(m->cpu_name = strdup(optarg));
 			msopts = 1;
@@ -496,7 +482,6 @@ int get_cmd_args(int argc, char *argv[], struct emul *emul,
 			break;
 		case 's':
 			machine_statistics_init(m, optarg);
-			native_code_translation_enabled = 0;
 			msopts = 1;
 			break;
 		case 'T':
@@ -673,12 +658,14 @@ int main(int argc, char *argv[])
 	const int constant_no = 0;
 	const int constant_false = 0;
 
-	struct emul **emuls;
+	struct emul *emul;
+	int config_file = 0;
+
 	char **diskimages = NULL;
 	int n_diskimages = 0;
-	int n_emuls;
 	int i;
 
+
 	progname = argv[0];
 
 
@@ -700,9 +687,6 @@ int main(int argc, char *argv[])
 	    SETTINGS_FORMAT_BOOL, (void *)&constant_false);
 
 	/*  Read-only settings:  */
-	settings_add(global_settings, "native_code_translation_enabled", 0,
-	    SETTINGS_TYPE_INT, SETTINGS_FORMAT_YESNO,
-	    (void *)&native_code_translation_enabled);
 	settings_add(global_settings, "single_step", 0,
 	    SETTINGS_TYPE_INT, SETTINGS_FORMAT_YESNO, (void *)&single_step);
 
@@ -723,16 +707,12 @@ int main(int argc, char *argv[])
 	timer_init();
 	useremul_init();
 
-	emuls = malloc(sizeof(struct emul *));
-	CHECK_ALLOCATION(emuls);
+	/*  Create a simple emulation setup:  */
+	emul = emul_new(NULL);
+	settings_add(global_settings, "emul", 1,
+	    SETTINGS_TYPE_SUBSETTINGS, 0, emul->settings);
 
-	/*  Allocate space for a simple emul setup:  */
-	n_emuls = 1;
-	emuls[0] = emul_new(NULL, 0);
-	settings_add(global_settings, "emul[0]", 1,
-	    SETTINGS_TYPE_SUBSETTINGS, 0, emuls[0]->settings);
-
-	get_cmd_args(argc, argv, emuls[0], &diskimages, &n_diskimages);
+	get_cmd_args(argc, argv, emul, &diskimages, &n_diskimages);
 
 	if (!skip_srandom_call) {
 		struct timeval tv;
@@ -741,23 +721,15 @@ int main(int argc, char *argv[])
 	}
 
 	/*  Print startup message:  */
-	debug("GXemul");
-#ifdef VERSION
-	debug(" " VERSION);
-#endif
-	debug("    Copyright (C) 2003-2007  Anders Gavare\n");
-	debug("Read the source code and/or documentation for "
-	    "other Copyright messages.\n\n");
-
-	if (emuls[0]->machines[0]->machine_type == MACHINE_NONE) {
-		n_emuls --;
-	} else {
-		for (i=0; i<n_diskimages; i++)
-			diskimage_add(emuls[0]->machines[0], diskimages[i]);
-	}
+	debug("GXemul "VERSION"    Copyright (C) 2003-2008  Anders Gavare\n"
+	    "Read the source code and/or documentation for other Copyright "
+	    "messages.\n\n");
 
 	/*  Simple initialization, from command line arguments:  */
-	if (n_emuls > 0) {
+	if (emul->machines[0]->machine_type != MACHINE_NONE) {
+		for (i=0; i<n_diskimages; i++)
+			diskimage_add(emul->machines[0], diskimages[i]);
+
 		/*  Make sure that there are no configuration files as well:  */
 		for (i=1; i<argc; i++)
 			if (argv[i][0] == '@') {
@@ -770,45 +742,44 @@ int main(int argc, char *argv[])
 			}
 
 		/*  Initialize one emul:  */
-		emul_simple_init(emuls[0]);
+		emul_simple_init(emul);
 	}
 
-	/*  Initialize emulations from config files:  */
+	/*  Initialize an emulation from a config file:  */
 	for (i=1; i<argc; i++) {
 		if (argv[i][0] == '@') {
-			char tmpstr[50];
 			char *s = argv[i] + 1;
-			if (strlen(s) == 0 && i+1 < argc &&
-			    argv[i+1][0] != '@') {
-				i++;
-				s = argv[i];
-			}
-			n_emuls ++;
-			CHECK_ALLOCATION(emuls = realloc(emuls,
-			    sizeof(struct emul *) * n_emuls));
 
-			/*  Always allow slave xterms when using multiple
-			    emulations:  */
+			if (config_file) {
+				fprintf(stderr, "More than one configuration "
+				    "file cannot be used.\n");
+				exit(1);
+			}
+
+			if (strlen(s) == 0 && i+1 < argc && *argv[i+1] != '@')
+				s = argv[++i];
+
+			/*  Always allow slave xterms:  */
 			console_allow_slaves(1);
 
-			/*  Destroy the temporary emuls[0], since it will
+			/*  Destroy the temporary emul, since it will
 			    be overwritten:  */
-			if (n_emuls == 1) {
-				emul_destroy(emuls[0]);
-				settings_remove(global_settings, "emul[0]");
+			if (emul != NULL) {
+				emul_destroy(emul);
+				settings_remove(global_settings, "emul");
+				emul = NULL;
 			}
 
-			emuls[n_emuls - 1] =
-			    emul_create_from_configfile(s, n_emuls - 1);
+			emul = emul_create_from_configfile(s);
 
-			snprintf(tmpstr, sizeof(tmpstr), "emul[%i]", n_emuls-1);
-			settings_add(global_settings, tmpstr, 1,
-			    SETTINGS_TYPE_SUBSETTINGS, 0,
-			    emuls[n_emuls-1]->settings);
+			settings_add(global_settings, "emul", 1,
+			    SETTINGS_TYPE_SUBSETTINGS, 0, emul->settings);
+
+			config_file = 1;
 		}
 	}
 
-	if (n_emuls == 0) {
+	if (emul->n_machines == 0) {
 		fprintf(stderr, "No emulations defined. Maybe you forgot to "
 		    "use -E xx and/or -e yy, to specify\nthe machine type."
 		    " For example:\n\n    %s -e 3max -d disk.img\n\n"
@@ -821,8 +792,8 @@ int main(int argc, char *argv[])
 	console_warn_if_slaves_are_needed(1);
 
 
-	/*  Run all emulations:  */
-	emul_run(emuls, n_emuls);
+	/*  Run the emulation:  */
+	emul_run(emul);
 
 
 	/*
@@ -831,8 +802,7 @@ int main(int argc, char *argv[])
 
 	console_deinit();
 
-	for (i=0; i<n_emuls; i++)
-		emul_destroy(emuls[i]);
+	emul_destroy(emul);
 
 	settings_remove_all(global_settings);
 	settings_destroy(global_settings);
